"""BLOT Trading Bots."""

from blot.bots.base import BaseBot
from blot.bots.sniper import SniperBot
from blot.bots.dca import DCABot
from blot.bots.copy_trade import CopyTradeBot
from blot.bots.grid import GridBot

__all__ = [
    "BaseBot",
    "SniperBot",
    "DCABot",
    "CopyTradeBot",
    "GridBot",
]

